==> chromium-47.0.2526.74.tar.xz: chromium-47.0.2526.74/docs/user_handle_mapping.md <==
For Chromium contributors that have different nicks on other domains.

| **@chromium.org** | **IRC nick(s)** | **@google.com** |
|:------------------|:----------------|:----------------|
| aa                | aboodman        | aa              |
| abw               | abw-cr          | abw             |
| acleung           | acleung         | acleung         |
| adamk             | aklein          | adamk           |
| ajwong            | awong           | ajwong          |
| aluebs            | aluebs          | aluebs          |
| amanda            | awalker         | awalker         |
| amit              | joshia          | joshia          |
| amstan            | amstan          | amstan          |
| ananta            | iyengar         | iyengar         |
| anantha           | anantha         | ananthak        |
| avi               | motownavi       | avi             |
| ben               | beng            | beng            |
| benhansen         | benhansen       | benhansen       |
| benhenry          | benry           | benhenry        |
| bnutter           |                 | bnutter         |
| bxx               | bxs             | bxx             |
| ccameron          | ccameron        | ccameron        |
| csharp            | csharp1         | csharp          |
| cthomp            | cthomp          | cthomp          |
| darin, fishd      | fishd           | darin           |
| dbeam             | danbeam         | dbeam           |
| dmurph            | dmurph          | dmurph          |
| eaugusti          | eriq            | eaugustine      |
| erg               | eglaysher       | erg             |
| eroman            | eroman          | ericroman       |
| esprehn           | esprehn         | esprehn         |
| evan              | evmar           | evanm           |
| feng              | feng            | fqian           |
| fmeawad           | fmeawad-cr      | fmeawad         |
| gab               | gabc            | gab             |
| hans              | hwennborg       | hwennborg       |
| haven             | periodic        | haven           |
| ian               | ifette          | ifette          |
| inferno           | inferno         | aarya           |
| iannucci          | iannucci        | iannucci        |
| jaikk             |                 | jaikk           |
| jansson           | jansson         | jansson         |
| janx              | janx            | janx            |
| jam               | jam2            | jabdelmalek     |
| jchaffraix        | jchaffraix      | jchaffraix      |
| jeremy            | jeremymos       | playmobil       |
| jln               | julien\`        | jln             |
| jochen            | jochen`__`      | eisinger        |
| johnnyg           | johnny_g        | johnnyg         |
| joi               | joisig          | joi             |
| jonross           | jonrossca       | jonross         |
| jshin             | jshin           | jungshik        |
| jww               | jww__           | jww             |
| jyasskin          | jyasskin        | jyasskin        |
| karen             | kareng          | kareng          |
| keescook          | kees            | keescook        |
| koz               |                 | jameskozianski  |
| kuchhal           | kuchhal         | rahulk          |
| levin             | dave_levin      | levin           |
| lfg               | lfg_            | lfg             |
| luken             | luken_chromium  | luken           |
| mark              | markmentovai    | mmentovai       |
| mattm             | mattm_c, mattm_g | mattm           |
| mbarbella         | mbarbella       | mbarbella       |
| mmeade            | mmeade          | mmeade          |
| mednik            | mednik          | mednik          |
| mgaba             | mgaba           | mgaba           |
| mlinck            | dullb0yj4ck     | mlinck          |
| msw               | msw_            | msw             |
| nick              | nickcarter      | ncarter         |
| oleg              |                 | olege           |
| ortuno            | gortuno         | ortuno          |
| pam               | pamg            | pamg            |
| paulirish         | paul_irish      | paulirish       |
| patrick           | pjohnson        | pjohnson        |
| peter             | beverloo        | beverloo        |
| phajdan.jr        | phajdan-jr      | phajdan         |
| rch               | RyanHamilton    | rch             |
| rdevlin.cronin    | rdcronin        | rdcronin        |
| reillyg           | reillyeon       | reillyg         |
| rlp               | rpetterson      | rlp             |
| robliao           | robliao         | robliao         |
| rsleevi           | sleevi, rsleevi | sleevi          |
| sarah             |                 | sarahgordon     |
| satish            | satish`_`       | satish          |
| scheglov          |                 | scheglov        |
| scottbyer         | sbyer           | scottbyer       |
| shans             |                 | shanestephens   |
| shrike            | shrike          | shrike          |
| smut              | Sana            | smut            |
| svaldez           | dvorak42, svaldez | svaldez         |
| tansell           | mithro@mithis.com | tansell         |
| thestig           | leiz            | thestig         |
| tim               | timsteele       | timsteele       |
| tony              | tony^work       | tc              |
| tonyg             | tonyg-cr        | tonyg           |
| tyoshino          | tyoshino        | tyoshino        |
| vabr              | vabr            | vabr            |
| vadimt            | vadimt          | vadimt          |
| viettrungluu      | trungl          | vtl             |
| wad               | redpig          | drewry          |
| wez               | real_wez        | wez             |
| wjmaclean         | seumas, wjmaclean | wjmaclean, wjm, seumas |
| yoz               | yaws            | yoz             |
| zmo               | zhenyao         | zmo             |

==> chromium-49.0.2618.9.tar.xz: chromium-49.0.2618.9/docs/user_handle_mapping.md <==
For Chromium contributors that have different nicks on other domains.

| **@chromium.org** | **IRC nick(s)** | **@google.com** |
|:------------------|:----------------|:----------------|
| aa                | aboodman        | aa              |
| abw               | abw-cr          | abw             |
| acleung           | acleung         | acleung         |
| adamk             | aklein          | adamk           |
| ajwong            | awong           | ajwong          |
| aluebs            | aluebs          | aluebs          |
| amanda            | awalker         | awalker         |
| amit              | joshia          | joshia          |
| amstan            | amstan          | amstan          |
| ananta            | iyengar         | iyengar         |
| anantha           | anantha         | ananthak        |
| avi               | motownavi       | avi             |
| ben               | beng            | beng            |
| benhansen         | benhansen       | benhansen       |
| benhenry          | benry           | benhenry        |
| bnutter           |                 | bnutter         |
| bxx               | bxs             | bxx             |
| ccameron          | ccameron        | ccameron        |
| csharp            | csharp1         | csharp          |
| cthomp            | cthomp          | cthomp          |
| darin, fishd      | fishd           | darin           |
| dbeam             | danbeam         | dbeam           |
| dmurph            | dmurph          | dmurph          |
| eaugusti          | eriq            | eaugustine      |
| erg               | eglaysher       | erg             |
| eroman            | eroman          | ericroman       |
| esprehn           | esprehn         | esprehn         |
| evan              | evmar           | evanm           |
| feng              | feng            | fqian           |
| fmeawad           | fmeawad-cr      | fmeawad         |
| gab               | gabc            | gab             |
| hans              | hwennborg       | hwennborg       |
| haven             | periodic        | haven           |
| ian               | ifette          | ifette          |
| inferno           | inferno         | aarya           |
| iannucci          | iannucci        | iannucci        |
| jaikk             |                 | jaikk           |
| jansson           | jansson         | jansson         |
| janx              | janx            | janx            |
| jam               | jam2            | jabdelmalek     |
| jchaffraix        | jchaffraix      | jchaffraix      |
| jeremy            | jeremymos       | playmobil       |
| jln               | julien\`        | jln             |
| jochen            | jochen\_\_      | eisinger        |
| johnnyg           | johnny\_g       | johnnyg         |
| joi               | joisig          | joi             |
| jonross           | jonrossca       | jonross         |
| jshin             | jshin           | jungshik        |
| jww               | jww\_\_         | jww             |
| jyasskin          | jyasskin        | jyasskin        |
| karen             | kareng          | kareng          |
| keescook          | kees            | keescook        |
| koz               |                 | jameskozianski  |
| kuchhal           | kuchhal         | rahulk          |
| levin             | dave\_levin     | levin           |
| lfg               | lfg\_           | lfg             |
| luken             | luken_chromium  | luken           |
| mark              | markmentovai    | mmentovai       |
| mattm             | mattm\_c, mattm\_g | mattm           |
| mbarbella         | mbarbella       | mbarbella       |
| mmeade            | mmeade          | mmeade          |
| mednik            | mednik          | mednik          |
| mgaba             | mgaba           | mgaba           |
| mlinck            | dullb0yj4ck     | mlinck          |
| msw               | msw\_           | msw             |
| nick              | nickcarter      | ncarter         |
| oleg              |                 | olege           |
| ortuno            | gortuno         | ortuno          |
| pam               | pamg            | pamg            |
| paulirish         | paul\_irish      | paulirish       |
| patrick           | pjohnson        | pjohnson        |
| peter             | beverloo        | beverloo        |
| phajdan.jr        | phajdan-jr      | phajdan         |
| rch               | RyanHamilton    | rch             |
| rdevlin.cronin    | rdcronin        | rdcronin        |
| reillyg           | reillyeon       | reillyg         |
| rlp               | rpetterson      | rlp             |
| robliao           | robliao         | robliao         |
| rsleevi           | sleevi, rsleevi | sleevi          |
| sarah             |                 | sarahgordon     |
| satish            | satish\_        | satish          |
| scheglov          |                 | scheglov        |
| scottbyer         | sbyer           | scottbyer       |
| shans             |                 | shanestephens   |
| shrike            | shrike          | shrike          |
| smut              | Sana            | smut            |
| svaldez           | dvorak42, svaldez | svaldez         |
| tansell           | mithro@mithis.com | tansell         |
| thestig           | leiz            | thestig         |
| tim               | timsteele       | timsteele       |
| tony              | tony^work       | tc              |
| tonyg             | tonyg-cr        | tonyg           |
| tyoshino          | tyoshino        | tyoshino        |
| vabr              | vabr            | vabr            |
| vadimt            | vadimt          | vadimt          |
| viettrungluu      | trungl          | vtl             |
| wad               | redpig          | drewry          |
| wez               | real\_wez       | wez             |
| wjmaclean         | seumas, wjmaclean | wjmaclean, wjm, seumas |
| yoz               | yaws            | yoz             |
| zmo               | zhenyao         | zmo             |
